[![ci](https://github.com/rvbCMTS/PySkinDose/actions/workflows/ci.yml/badge.svg)](https://github.com/rvbCMTS/PySkinDose/actions/workflows/ci.yml) [![codecov](https://codecov.io/gh/rvbCMTS/PySkinDose/branch/master/graph/badge.svg?token=2O32UO12V6)](https://codecov.io/gh/rvbCMTS/PySkinDose) [![Documentation Status](https://readthedocs.org/projects/pyskindose/badge/?version=latest)](http://pyskindose.readthedocs.io/en/latest/?badge=latest)

# pyskindose

author: Max Hellström

A python program for calculating 1-dimensional maximum estimated skin dose (ESD<sub>max</sub>).

Implementation of a 3D skin dose mapping procedure are currently in process.

Stay tuned!
